Hello!

This is `tdm-lsuko`, the first API ever created by yours truly (Drew Sukova) as part of the Purdue Data Mine seminar projects for TDM301.

The framework is the same as all the other projects, in that we take an IMDb ID and return the rating of the desired content.